/*
 * Copyright (C) 2003 John David Ratliff
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package gui.view;

import java.io.File;

import javax.swing.filechooser.FileFilter;

/**
 * A file filter for JFileChoosers for Java Source files.
 *
 * @author John David Ratliff
 * @version 1.1, 09/20/03
 */
public class JavaFileFilter extends FileFilter {
    private final String description = "Java Source Files (*.java)";
    private final String extention = "java";

    /**
     * Gets the description for the JFileChooser.
     *
     * @return The file filter description.
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * Checks if this filter should 'accept' on a given File.
     *
     * @param file The File to check.
     *
     * @return true if this file should be accepted; false otherwise.
     */
    public boolean accept(File file) {
        if (file.isDirectory()) {
            return true;
        }

        return file.getName().toLowerCase().endsWith(this.extention);
    }
}
